@@ -5,84 +5,98 @@
 
 #pragma once
 
-#include <spdlog/sinks/base_sink.h>
-#include <spdlog/details/null_mutex.h>
-#include <spdlog/details/file_helper.h>
-#include <spdlog/fmt/fmt.h>
+#include "../details/file_helper.h"
+#include "../details/null_mutex.h"
+#include "../fmt/fmt.h"
+#include "base_sink.h"
 
 #include <algorithm>
+#include <cerrno>
 #include <chrono>
 #include <cstdio>
 #include <ctime>
 #include <mutex>
 #include <string>
-#include <cerrno>
 
-namespace spdlog
-{
-namespace sinks
-{
+namespace spdlog {
+namespace sinks {
 /*
  * Trivial file sink with single file as target
  */
 template<class Mutex>
-class simple_file_sink : public base_sink < Mutex >
+class simple_file_sink SPDLOG_FINAL : public base_sink<Mutex>
 {
 public:
-    explicit simple_file_sink(const filename_t &filename, bool truncate = false):_force_flush(false)
+    explicit simple_file_sink(const filename_t &filename, bool truncate = false)
+        : _force_flush(false)
     {
         _file_helper.open(filename, truncate);
     }
-    void flush() override
-    {
-        _file_helper.flush();
-    }
+
     void set_force_flush(bool force_flush)
     {
         _force_flush = force_flush;
     }
 
 protected:
-    void _sink_it(const details::log_msg& msg) override
+    void _sink_it(const details::log_msg &msg) override
     {
         _file_helper.write(msg);
-        if(_force_flush)
+        if (_force_flush)
+        {
             _file_helper.flush();
+        }
     }
+
+    void _flush() override
+    {
+        _file_helper.flush();
+    }
+
 private:
     details::file_helper _file_helper;
     bool _force_flush;
 };
 
-typedef simple_file_sink<std::mutex> simple_file_sink_mt;
-typedef simple_file_sink<details::null_mutex> simple_file_sink_st;
+using simple_file_sink_mt = simple_file_sink<std::mutex>;
+using simple_file_sink_st = simple_file_sink<details::null_mutex>;
 
 /*
  * Rotating file sink based on size
  */
 template<class Mutex>
-class rotating_file_sink : public base_sink < Mutex >
+class rotating_file_sink SPDLOG_FINAL : public base_sink<Mutex>
 {
 public:
-    rotating_file_sink(const filename_t &base_filename,
-                       std::size_t max_size, std::size_t max_files) :
-        _base_filename(base_filename),
-        _max_size(max_size),
-        _max_files(max_files),
-        _current_size(0),
-        _file_helper()
+    rotating_file_sink(filename_t base_filename, std::size_t max_size, std::size_t max_files)
+        : _base_filename(std::move(base_filename))
+        , _max_size(max_size)
+        , _max_files(max_files)
     {
         _file_helper.open(calc_filename(_base_filename, 0));
-        _current_size = _file_helper.size(); //expensive. called only once
+        _current_size = _file_helper.size(); // expensive. called only once
     }
 
-    void flush() override
+    // calc filename according to index and file extension if exists.
+    // e.g. calc_filename("logs/mylog.txt, 3) => "logs/mylog.3.txt".
+    static filename_t calc_filename(const filename_t &filename, std::size_t index)
     {
-        _file_helper.flush();
+        typename std::conditional<std::is_same<filename_t::value_type, char>::value, fmt::MemoryWriter, fmt::WMemoryWriter>::type w;
+        if (index != 0u)
+        {
+            filename_t basename, ext;
+            std::tie(basename, ext) = details::file_helper::split_by_extenstion(filename);
+            w.write(SPDLOG_FILENAME_T("{}.{}{}"), basename, index, ext);
+        }
+        else
+        {
+            w.write(SPDLOG_FILENAME_T("{}"), filename);
+        }
+        return w.str();
     }
 
 protected:
-    void _sink_it(const details::log_msg& msg) override
+    void _sink_it(const details::log_msg &msg) override
     {
         _current_size += msg.formatted.size();
         if (_current_size > _max_size)
@@ -93,23 +107,17 @@ protected:
         _file_helper.write(msg);
     }
 
-private:
-    static filename_t calc_filename(const filename_t& filename, std::size_t index)
+    void _flush() override
     {
-        std::conditional<std::is_same<filename_t::value_type, char>::value, fmt::MemoryWriter, fmt::WMemoryWriter>::type w;
-        if (index)
-            w.write(SPDLOG_FILENAME_T("{}.{}"), filename, index);
-        else
-            w.write(SPDLOG_FILENAME_T("{}"), filename);
-        return w.str();
+        _file_helper.flush();
     }
 
+private:
     // Rotate files:
-    // log.txt -> log.txt.1
-    // log.txt.1 -> log.txt.2
-    // log.txt.2 -> log.txt.3
-    // lo3.txt.3 -> delete
-
+    // log.txt -> log.1.txt
+    // log.1.txt -> log.2.txt
+    // log.2.txt -> log.3.txt
+    // log.3.txt -> delete
     void _rotate()
     {
         using details::os::filename_to_str;
@@ -126,13 +134,14 @@ private:
                     throw spdlog_ex("rotating_file_sink: failed removing " + filename_to_str(target), errno);
                 }
             }
-            if (details::file_helper::file_exists(src) && details::os::rename(src, target))
+            if (details::file_helper::file_exists(src) && details::os::rename(src, target) != 0)
             {
                 throw spdlog_ex("rotating_file_sink: failed renaming " + filename_to_str(src) + " to " + filename_to_str(target), errno);
             }
         }
         _file_helper.reopen(true);
     }
+
     filename_t _base_filename;
     std::size_t _max_size;
     std::size_t _max_files;
@@ -140,35 +149,40 @@ private:
     details::file_helper _file_helper;
 };
 
-typedef rotating_file_sink<std::mutex> rotating_file_sink_mt;
-typedef rotating_file_sink<details::null_mutex>rotating_file_sink_st;
+using rotating_file_sink_mt = rotating_file_sink<std::mutex>;
+using rotating_file_sink_st = rotating_file_sink<details::null_mutex>;
 
 /*
  * Default generator of daily log file names.
  */
 struct default_daily_file_name_calculator
 {
-    // Create filename for the form basename.YYYY-MM-DD_hh-mm
-    static filename_t calc_filename(const filename_t& basename)
+    // Create filename for the form filename.YYYY-MM-DD_hh-mm.ext
+    static filename_t calc_filename(const filename_t &filename)
     {
         std::tm tm = spdlog::details::os::localtime();
+        filename_t basename, ext;
+        std::tie(basename, ext) = details::file_helper::split_by_extenstion(filename);
         std::conditional<std::is_same<filename_t::value_type, char>::value, fmt::MemoryWriter, fmt::WMemoryWriter>::type w;
-        w.write(SPDLOG_FILENAME_T("{}_{:04d}-{:02d}-{:02d}_{:02d}-{:02d}"), basename, tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday, tm.tm_hour, tm.tm_min);
+        w.write(SPDLOG_FILENAME_T("{}_{:04d}-{:02d}-{:02d}_{:02d}-{:02d}{}"), basename, tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday,
+            tm.tm_hour, tm.tm_min, ext);
         return w.str();
     }
 };
 
 /*
- * Generator of daily log file names in format basename.YYYY-MM-DD
+ * Generator of daily log file names in format basename.YYYY-MM-DD.ext
  */
 struct dateonly_daily_file_name_calculator
 {
     // Create filename for the form basename.YYYY-MM-DD
-    static filename_t calc_filename(const filename_t& basename)
+    static filename_t calc_filename(const filename_t &filename)
     {
         std::tm tm = spdlog::details::os::localtime();
+        filename_t basename, ext;
+        std::tie(basename, ext) = details::file_helper::split_by_extenstion(filename);
         std::conditional<std::is_same<filename_t::value_type, char>::value, fmt::MemoryWriter, fmt::WMemoryWriter>::type w;
-        w.write(SPDLOG_FILENAME_T("{}_{:04d}-{:02d}-{:02d}"), basename, tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday);
+        w.write(SPDLOG_FILENAME_T("{}_{:04d}-{:02d}-{:02d}{}"), basename, tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday, ext);
         return w.str();
     }
 };
@@ -177,30 +191,25 @@ struct dateonly_daily_file_name_calculator
  * Rotating file sink based on date. rotates at midnight
  */
 template<class Mutex, class FileNameCalc = default_daily_file_name_calculator>
-class daily_file_sink :public base_sink < Mutex >
+class daily_file_sink SPDLOG_FINAL : public base_sink<Mutex>
 {
 public:
-    //create daily file sink which rotates on given time
-    daily_file_sink(
-        const filename_t& base_filename,
-        int rotation_hour,
-        int rotation_minute) : _base_filename(base_filename),
-        _rotation_h(rotation_hour),
-        _rotation_m(rotation_minute)
+    // create daily file sink which rotates on given time
+    daily_file_sink(filename_t base_filename, int rotation_hour, int rotation_minute)
+        : _base_filename(std::move(base_filename))
+        , _rotation_h(rotation_hour)
+        , _rotation_m(rotation_minute)
     {
         if (rotation_hour < 0 || rotation_hour > 23 || rotation_minute < 0 || rotation_minute > 59)
+        {
             throw spdlog_ex("daily_file_sink: Invalid rotation time in ctor");
+        }
         _rotation_tp = _next_rotation_tp();
         _file_helper.open(FileNameCalc::calc_filename(_base_filename));
     }
 
-    void flush() override
-    {
-        _file_helper.flush();
-    }
-
 protected:
-    void _sink_it(const details::log_msg& msg) override
+    void _sink_it(const details::log_msg &msg) override
     {
         if (std::chrono::system_clock::now() >= _rotation_tp)
         {
@@ -210,6 +219,11 @@ protected:
         _file_helper.write(msg);
     }
 
+    void _flush() override
+    {
+        _file_helper.flush();
+    }
+
 private:
     std::chrono::system_clock::time_point _next_rotation_tp()
     {
@@ -221,9 +235,10 @@ private:
         date.tm_sec = 0;
         auto rotation_time = std::chrono::system_clock::from_time_t(std::mktime(&date));
         if (rotation_time > now)
+        {
             return rotation_time;
-        else
-            return std::chrono::system_clock::time_point(rotation_time + std::chrono::hours(24));
+        }
+        return {rotation_time + std::chrono::hours(24)};
     }
 
     filename_t _base_filename;
@@ -233,7 +248,8 @@ private:
     details::file_helper _file_helper;
 };
 
-typedef daily_file_sink<std::mutex> daily_file_sink_mt;
-typedef daily_file_sink<details::null_mutex> daily_file_sink_st;
-}
-}
+using daily_file_sink_mt = daily_file_sink<std::mutex>;
+using daily_file_sink_st = daily_file_sink<details::null_mutex>;
+
+} // namespace sinks
+} // namespace spdlog
