@@ -3,25 +3,18 @@
 // Distributed under the MIT License (http://opensource.org/licenses/MIT)
 //
 
-
 #pragma once
 
-#include "spdlog/details/log_msg.h"
+#include "../details/log_msg.h"
 
-namespace spdlog
-{
-namespace sinks
-{
+namespace spdlog {
+namespace sinks {
 class sink
 {
 public:
-    sink()
-    {
-        _level = level::trace;
-    }
+    virtual ~sink() = default;
 
-    virtual ~sink() {}
-    virtual void log(const details::log_msg& msg) = 0;
+    virtual void log(const details::log_msg &msg) = 0;
     virtual void flush() = 0;
 
     bool should_log(level::level_enum msg_level) const;
@@ -29,8 +22,7 @@ public:
     level::level_enum level() const;
 
 private:
-    level_t _level;
-
+    level_t _level{level::trace};
 };
 
 inline bool sink::should_log(level::level_enum msg_level) const
@@ -48,6 +40,5 @@ inline level::level_enum sink::level() const
     return static_cast<spdlog::level::level_enum>(_level.load(std::memory_order_relaxed));
 }
 
-}
-}
-
+} // namespace sinks
+} // namespace spdlog
